@@ -8,11 +8,12 @@ from asyncio import BaseProtocol, BaseTransport, DatagramTransport
 from asyncio.events import AbstractEventLoop
 from datetime import datetime
 from ipaddress import IPv4Address, IPv6Address, ip_address
-from typing import Awaitable, Callable, MutableMapping, Optional, Tuple, Union, cast
+from typing import Awaitable, Callable, MutableMapping, Optional, Tuple, cast
 from urllib.parse import urlsplit, urlunsplit
 
 from aiohttp.http_parser import HeadersParser
 
+from async_upnp_client.const import AddressTupleV6Type, AddressTupleVXType, IPvXAddress
 from async_upnp_client.utils import CaseInsensitiveDict
 
 SSDP_PORT = 1900
@@ -33,11 +34,6 @@ SSDP_BYEBYE = "ssdp:byebye"
 _LOGGER = logging.getLogger(__name__)
 _LOGGER_TRAFFIC_SSDP = logging.getLogger("async_upnp_client.traffic.ssdp")
 
-IPvXAddress = Union[IPv4Address, IPv6Address]
-AddressTupleV4Type = Tuple[str, int]
-AddressTupleV6Type = Tuple[str, int, int, int]
-AddressTupleVXType = Union[AddressTupleV4Type, AddressTupleV6Type]
-
 
 def get_host_string(addr: AddressTupleVXType) -> str:
     """Construct host string from address tuple."""
@@ -123,7 +119,7 @@ def decode_ssdp_packet(
         lines.append(b"")
 
     parsed_headers, _ = HeadersParser().parse_headers(lines)
-    headers = CaseInsensitiveDict(**parsed_headers)
+    headers = CaseInsensitiveDict(**dict(parsed_headers))
 
     # adjust some headers
     if "location" in headers:
@@ -161,6 +157,7 @@ class SsdpProtocol(BaseProtocol):
 
     def connection_made(self, transport: BaseTransport) -> None:
         """Handle connection made."""
+        _LOGGER.debug("Connection made, transport: %s", self.transport)
         self.transport = cast(DatagramTransport, transport)
 
         if self.on_connect:
@@ -179,10 +176,11 @@ class SsdpProtocol(BaseProtocol):
     def error_received(self, exc: Exception) -> None:
         """Handle an error."""
         # pylint: disable=no-self-use
-        _LOGGER.debug("Received error: %s", exc)
+        _LOGGER.error("Received error: %s, transport: %s", exc, self.transport)
 
     def connection_lost(self, exc: Optional[Exception]) -> None:
         """Handle connection lost."""
+        _LOGGER.debug("Lost connection, transport: %s", self.transport)
 
 
 def get_source_ip_from_target_ip(target_ip: IPvXAddress) -> IPvXAddress:
@@ -210,6 +208,7 @@ def get_ssdp_socket(
     # create socket
     sock = socket.socket(source[0], source[1], source[2])
     sock.setsockopt(socket.SOL_SOCKET, socket.SO_REUSEADDR, 1)
+    sock.setsockopt(socket.SOL_SOCKET, socket.SO_BROADCAST, 1)
 
     # multicast
     if target_ip.is_multicast:
